% Team 2 Cummins Energy Savings
% Simulation Package 

function [solar_time,T_Collector_out,TotalMassFlow,Total_Beam,True_powerout,Collector_efficiency,heat_Useful,T_out_heatexchange,SystemEfficiencyTrue,Annual_Energy_MWh,Annual_Energy_dol, HE_efficiency,HEheat_Useful]= SIM(NumEng,Day)
disp('Welcome to Team 2''s Simulation!')
numberofpoints = 24;

%% Exhaust Properties
rho_air = 0.7461; % kg/m^3 [1]
Cp_air = 1.0061; % kJ/kg*K
K_air = 1.4019; % Specific Heat Ratio cp/cv
Cv_air = Cp_air / K_air; % kJ/kg*K
prop_air = [ rho_air Cp_air K_air Cv_air]; 

Cp = ones(1,numberofpoints);
Cp = Cp.* Cp_air;

%% ENGINE SERIES DETAILS
%{
% Engine Power rating values. All values are in Horsepower.
ISB_HP = [ 185 190 205 210 225 240 245 260 275 ];
ISC_HP = [ 225 240 260 285 300 315 330 350 ];
ISL_HP = [ 310 330 ];
ISM_HP = [ 280 310 330 350 370 400 425 450 500 ];
ISX_HP = [ 400 450 475 500 600 ];

% Exhaust temperature values.
% All values are in Farenheit.

ISB_OUT_TEMP = [ 698 801 831 857 892 812 812 886 956];
ISC_OUT_TEMP = [ 706 746 765 833 860 919 927 966 ];
ISL_OUT_TEMP = [ 891 933 ];
ISM_OUT_TEMP = [ 670 721 742 720 737 737 969 789 965 ]; 
ISX_OUT_TEMP = [ 655 696 842 905 975 ];
%}

% Mass flow rate values.
% All values are in CFM.
ISB_CFM_OUT = [ 1257 1250 1246 1313 1311 1456 1456 1592 1673 ];
ISC_CFM_OUT = [ 1417 1485 1578 1531 1578 1686 1758 1841 ];
ISL_CFM_OUT = [ 1681 1740 ];
ISM_CFM_OUT = [ 1523 1528 1610 1778 1853 1853 2171 2030 2341 ];
ISX_CFM_OUT = [ 2036 2218 2504 2633 3202 ];
% CONVERSION TO VALUES IN kg/s.

ISB_kgs_OUT = ISB_CFM_OUT*(.0283168)*(1/60) * rho_air;
ISC_kgs_OUT = ISC_CFM_OUT*(.0283168)*(1/60) * rho_air;
ISL_kgs_OUT = ISL_CFM_OUT*(.0283168)*(1/60) * rho_air;
ISM_kgs_OUT = ISM_CFM_OUT*(.0283168)*(1/60) * rho_air;
ISX_kgs_OUT = ISX_CFM_OUT*(.0283168)*(1/60) * rho_air;

ISB_avg_mdot = mean(ISB_kgs_OUT);
ISC_avg_mdot = mean(ISC_kgs_OUT);
ISL_avg_mdot = mean(ISL_kgs_OUT);
ISM_avg_mdot = mean(ISM_kgs_OUT);
ISX_avg_mdot = mean(ISX_kgs_OUT);
EngineAverages = eye(5);
EngineAveragesRow = [ISB_avg_mdot, ISC_avg_mdot, ISL_avg_mdot,ISM_avg_mdot, ISX_avg_mdot];
EngineAverages(1,1) = EngineAveragesRow(1);
EngineAverages(2,2) = EngineAveragesRow(2);
EngineAverages(3,3) = EngineAveragesRow(3);
EngineAverages(4,4) = EngineAveragesRow(4);
EngineAverages(5,5) = EngineAveragesRow(5);



%{
EngineAverages(1,:) = EngineAverages(1,1);
EngineAverages(2,:) = EngineAverages(2,1);
EngineAverages(3,:) = EngineAverages(3,1);
EngineAverages(4,:) = EngineAverages(4,1);
EngineAverages(5,:) = EngineAverages(5,1);
%}
%% Types of engines and mass flow
%{
massFlowOut = [ ];
i = 1;
j = 1;
k = 1;
NumOfEngines = 0;
EngineSeries = 0;
NumEng = zeros(1,5);

while EngineSeries ~= 6
    disp('Please choose 1 = ISB,2 = ISC,3 = ISL,4 = ISM,5 = ISX,6 = DONE')
    EngineSeries = input('Which engine series is this?');
    % Entries allowed: ISB,ISC,ISL,ISM,ISX.

    if EngineSeries == 1
        massflow = ISB_kgs_OUT;
        i = 1;
    elseif EngineSeries == 2
        massflow = ISC_kgs_OUT;
        i = 2;
    elseif EngineSeries == 3
        massflow = ISL_kgs_OUT;
        i = 3;
    elseif EngineSeries == 4
        massflow = ISM_kgs_OUT;
        i = 4;
    elseif EngineSeries == 5
        massflow = ISX_kgs_OUT;
        i = 5;
    elseif EngineSeries == 6
        break;
    else
        error('Please select a value between 1-6.')
    end

   NumOfEngines = input('How many of these engines are running currently?');
   NumEng(i) = NumOfEngines;
%} 

CombinedMassFlow = EngineAverages*NumEng; % Store the number of engine series into combined mass flow array. The sum of this array is the total mass flow.
%end % END WHILE
%disp(' The mass flow rate [kg/s] for different types of engines in the series are:')
TotalMassFlow = sum(CombinedMassFlow);


array1 = ones(1,numberofpoints);
TotalMassFlow = TotalMassFlow.* array1;

%TotalMassFlow = 44; % Test variable for GUI 
%% Temperature Exhaust
array2 = ones(1,numberofpoints);
T_in = 400.*array2; % Degree (F) {typically 400F}
T_C = (T_in - 32).* (5/9); % Output Degree Celsius
T_K = T_C + 273.15; % Output convert to Kelvin.
Tout_exhaustF = 212;% [Degree F] (corresponds to 100C, picked from as design parameter that determines size of heat exchanger.
Tout_exhaust = ((Tout_exhaustF-32).*(5/9)) + 273.15; % [K]

%% Working Fluid Properties - Butane
% DENSITY
rho_but = 2.48; % [kg/m^3]
% ABSOLUTE VISCOSITY
visc_but = 7*10^(-6); % [Pa*s]
% SPECIFIC HEAT
Cp_but=1.675; %[kJ/kg*K]
Cp_but_turb=2.2; %[kJ/kg*K]
gamma = 1.096; % Specific heat ratios
% THERMAL CONDUCTIVITY
k_but = 1.70*10^(-2); %[W/m*K]
% PRANDTL NUMBER
Pr_but = 0.69; % [UNITLESS]
% MASS FLOW RATE
mdot_but =  7.00; % [kg/s]
% RUN Solar_Thermal_Collectors function. (Daily)
% Day = input('What day of the year is it? (1-365)');

[solar_time,T_Collector_out,Total_Beam,Collector_efficiency,heat_Useful] = Solar_Thermal_Collectors(Day);

% TEMPERATURE INLET
Tin_but = T_Collector_out; % [K]
% Run code from solar collectors.
% TEMPERATURE OUTLET
% Tout_but = 145 + 273; % [K] with 50 ISX

%% Heat Generated From Exhaust Gases
Q_exhaust = TotalMassFlow.*Cp.*(T_K - Tout_exhaust) % Units [kW]
%% Heat Available After Exchange
heat_exchange_efficiency = .75;
heat_exchange_efficiency2 = .55;
Q_available = Q_exhaust.*heat_exchange_efficiency;
T_out_heatexchange = (Q_available./(mdot_but.*Cp_but))+ Tin_but.*heat_exchange_efficiency2;
T_out_C = T_out_heatexchange - 273.15;
HEheat_Useful = (Q_available + Tin_but*heat_exchange_efficiency2.*(mdot_but*Cp_but))./2;
HE_efficiency = HEheat_Useful ./ Q_exhaust;
%% Turbine Code
Poweroutput = 0.5*Q_available;
T_turbine_in = T_out_heatexchange;
P_turbine_in = 1000; %call from pipe loss code kPa
P_turbine_out = 500; %kPa
T_turbine_out = T_turbine_in .* ((P_turbine_out./P_turbine_in) .^(1-(1/gamma)));
dh = Cp_but_turb.*(T_turbine_in-T_turbine_out); % Units: [kJ/kg*K]00

True_powerout = mdot_but.*dh; % Units: [kW]
Poweraccuracy = True_powerout/Poweroutput *100;
%% Compressor Code
T_compress_in = T_turbine_out;
P_compress_out = 1100; %kPa 
P_compress_in = P_turbine_out; %%% WE can call from pipe loss code.
T_compress_out = T_compress_in.* ((P_compress_out ./ P_compress_in) .^(1-(1/gamma)));


%% Annual Energy
SystemEfficiencyGuess = (Poweroutput./Q_exhaust)*100; % Percent
SystemEfficiencyTrue = (True_powerout./Q_exhaust)*100;%*100; % Percent
%disp(' ')
%disp('The annual energy provided in kJ is:')
Annual_Energy = True_powerout.*3600*24*365; % Units [kJ/year]
Annual_Energy_GJ = Annual_Energy./1000000; % Units [GJ/year]
Annual_Energy_MWh = Annual_Energy_GJ./1000*278; % Units [MWh/year]
Annual_Energy_dol = Annual_Energy_MWh.*.085*1000; % Units [$/year]
%disp(' ')
%disp('The annual energy consumed by the CTC in kJ is:')
Annual_Consumption = 7.6*10^(11); % Units [kJ/year]
%disp(' ')
%disp('The annual energy percentage saved is:')
Annual_Energy_Savings = (Annual_Energy/Annual_Consumption)*100; % Percent





