% Solar Thermal Collectors
% Senior Design Project
function [solar_time, T_Collector_out,Total_Beam,Collector_efficiency,heat_Useful] = Solar_Thermal_Collectors(day)

if day > 365
    day = 365;
end

numberofpoints = 24;
SRT = xlsread('Solar_Power','Sheet1','G11:G375'); % Sunrise Time
SST = xlsread('Solar_Power','Sheet1','H11:H375'); % Sunset Time


time_rise_solar = SRT(day);
time_set_solar = SST(day);
solar_time = linspace(time_rise_solar,time_set_solar,numberofpoints);
solar_angle = zeros(1,numberofpoints);
zenith = zeros(1,numberofpoints);
alpha = zeros(1,numberofpoints);
as = zeros(1,numberofpoints);
cosi = zeros(1,numberofpoints);


%%% Coordinates for Indiana %%%
I_o = 1367; %W/m^2
a = 0.14;
h = .192; % km above sea level
AM = 1.5; % Air Mass Index [100 units]
aw = 0;
rho = 0.4;


lamda = Coordinate_Time(39,12,4.49298); % lattitude
W = Coordinate_Time(85,54,13.0428); % Lonigtude
beta = 0;


%%% Average Insolation Equation %%%
I_local = I_o.*((1-a.*h).*(0.7.^(((AM).^0.678))) + (a.*h));
declination = 23.44.*sind(360*((day-80)/365.25));

i = 1;
j = 1;

while i <= numberofpoints
    solar_angle(i) = (360/24).*(solar_time(i) - 12);
    zenith(i) = acosd(sind(declination).*sind(lamda) + ...
        cosd(declination).*cosd(lamda).*cosd(solar_angle(i)));
    
    alpha(i) = (90 - zenith(i));
    as(i) = sind(cosd(declination).*sind(solar_angle(i))./cosd(alpha(i)));
    
    
    if lamda > declination
        as(j) = 180 - abs(as(i));
    else
        as(j) = as(i);
    end
    
    cosi(i) = cosd(alpha(i)).*cosd(as(i)).*sind(beta) + sind(alpha(i)).*cosd(beta);
    
    j = j+1;
    i = i+1;
end

Direct_Beam = I_local.*cosi; % Regardless of what we use this is correct (Horizontal equations and elevated equations)
z = 1;
%{
while z <= numberofpoints
    if Direct_Beam(z) < 0
        Direct_Beam(z) = 0;
    else
        Direct_Beam(z) = Direct_Beam(z);
    end
    z = z+1;
end
%} 
if (day < 32)
    C = 0.048;
    Temperature_ambient = 2 + 273;
elseif (day < 59) && (day >= 32)
    C = 0.050;
    Temperature_ambient(1:numberofpoints) = 4.556 + 273;
elseif (day < 90) && (day >=59)
    C = 0.061;
    Temperature_ambient(1:numberofpoints) = 10.944 + 273;
elseif (day < 120) && (day >=90)
    C = 0.087;
    Temperature_ambient(1:numberofpoints) = 17.444 + 273;
elseif (day < 151) && ( day >= 120)
    C = .111;
    Temperature_ambient(1:numberofpoints) = 22.667 + 273;
elseif (day < 181) && (day >= 151)
    C = .124;
    Temperature_ambient(1:numberofpoints) =  27.722 + 273;
elseif (day < 212) && (day >=181)
    C = .126;
    Temperature_ambient(1:numberofpoints) = 29.444 + 273;
elseif (day < 243) && (day >= 212)
    C = .112;
    Temperature_ambient(1:numberofpoints) = 28.889 + 273;
elseif (day < 273) && (day >= 243)
    C = .082;
    Temperature_ambient(1:numberofpoints) = 25.333 + 273;
elseif (day < 304) && (day >= 273)
    C = 0.063;
    Temperature_ambient(1:numberofpoints) = 18.333 + 273;
elseif (day < 334) && (day >= 304)
    C = 0.053;
    Temperature_ambient(1:numberofpoints) = 11.111 + 273;
else
    C = 0.057;
    Temperature_ambient(1:numberofpoints) = 3.333 + 273;
end

Diffuse_Beam = C.*I_local;
Total_Beam = Direct_Beam + Diffuse_Beam;
 

%% Collector Energy Balance
massflownbutane(1:numberofpoints) = 7; %kg/s
cp_nbutane = 1900; %J/kg*K
Collector_area = 2100; %m^2 CTC Roof
Solar_transmittance = 0.92; %AE Collector
Solar_Absorptance = 0.96; %AE Collector
Collector_storage = 0; %J 
Global_Conductance = 8; %W/m^2*K
Insolation = Total_Beam * Solar_transmittance;  %correct %W/m^2
Q_solar = Insolation .* Collector_area
G = massflownbutane / Collector_area;
T_f_in = 80 + 273.15;
T_f_out = T_f_in + (50 .* C ./ .126) .* (Insolation ./ max(Insolation));
F_r = (G * cp_nbutane  .*( T_f_out - T_f_in )) ./ (( Solar_Absorptance .* Insolation) - Global_Conductance * ( T_f_in - Temperature_ambient ));
heat_Useful = (F_r .* Insolation .* Solar_Absorptance .* Collector_area - (Global_Conductance .* (T_f_in - Temperature_ambient) .* F_r .* Collector_area))./1000;
%in kwT
%Heat_Useful = abs(heat_Useful)
%Heat_lost = (Global_Conductance .* Collector_area .* (T_f_out + 273.15 - Temperature_ambient))
%Heat_lost = (Insolation .* Collector_area) - heat_Useful;
Temperaturedifference = heat_Useful ./ ((massflownbutane.*cp_nbutane)./1000);

T_Collector_out = Temperaturedifference + T_f_in; %K
T_Collector_out_C = T_Collector_out - 273.15; %C

TotalTempchange = sum(Temperaturedifference); % Not used.

%Heat_total = heat_Useful + Heat_lost;
Heat_input = Insolation .* Collector_area;

Collector_efficiency = heat_Useful ./ Heat_input % Should be 30-40%
end


