% Solar Thermal Collectors year
% Senior Design Project

clear all
clc, close all

numberofpoints = 24;
SRT = xlsread('Solar_Power','Sheet1','G11:G375'); % Sunrise Time
SST = xlsread('Solar_Power','Sheet1','H11:H375'); % Sunset Time

solar_angle = zeros(365,numberofpoints);
zenith = zeros(365,numberofpoints);
alpha = zeros(365,numberofpoints);
as = zeros(365,numberofpoints);
cosi = zeros(365,numberofpoints);
solar_time_matrix = zeros(365,numberofpoints); % Size 365x20
Direct_Beam = zeros(365,numberofpoints);

Diffuse_Beam = zeros(365,numberofpoints);
Reflected_Beam = zeros(365,numberofpoints);
Total_Beam = zeros(365,numberofpoints);

lamda = Coordinate_Time(39,12,4.49298); % lattitude
W = Coordinate_Time(85,54,13.0428); % Lonigtude
beta = 0;
I_o = 1367; %W/m^2
a = 0.14;
h = .192; % km above sea level
AM = 1.5; % Air Mass Index [100 units]
aw = 0;
rho = 0.4;
I_local = I_o.*((1-a.*h).*(0.7.^(((AM).^0.678))) + (a.*h));
i = 1; j = 1;

for day = 1:365
    
    time_rise_solar = SRT(day); % Reads the sunrise time, assigns here.
    time_set_solar = SST(day); % Reads the sunset time, assigns here.
    solar_time = linspace(time_rise_solar,time_set_solar,numberofpoints)'; 
    declination = 23.44.*sind(360*((day-80)/365.25));

while i <= numberofpoints % While i runs through numberofpoints evenly spaced columns
    solar_time_matrix(j,i) = solar_time(i);    % This should assign the solar times for each day.  
    solar_angle(j,i) = (360/24).*(solar_time_matrix(j,i) - 12);
    
    zenith(j,i) = acosd(sind(declination).*sind(lamda) + ...
        cosd(declination).*cosd(lamda).*cosd(solar_angle(j,i)));
    alpha(j,i) = (90 - zenith(j,i));
    as(j,i) = sind(cosd(declination).*sind(solar_angle(j,i))./cosd(alpha(j,i)));
    
    if lamda > declination
        as(j,i) = 180 - abs(as(j,i));
    end % END IF STATEMENT
    
 cosi(j,i) = cosd(alpha(j,i)).*cosd(as(j,i)).*sind(beta) + sind(alpha(j,i)).*cosd(beta);
 Direct_Beam(j,i) = I_local.*cosi(j,i);
 
 %% CLOUDINESS FACTOR
 if (day < 32)
    C = 0.048;
    Temperature_ambient = 2 + 273;
elseif (day < 59) && (day >= 32)
    C = 0.050;
    Temperature_ambient(1:numberofpoints) = 4.556 + 273;
elseif (day < 90) && (day >=59)
    C = 0.061;
    Temperature_ambient(1:numberofpoints) = 10.944 + 273;
elseif (day < 120) && (day >=90)
    C = 0.087;
    Temperature_ambient(1:numberofpoints) = 17.444 + 273;
elseif (day < 151) && ( day >= 120)
    C = .111;
    Temperature_ambient(1:numberofpoints) = 22.667 + 273;
elseif (day < 181) && (day >= 151)
    C = .124;
    Temperature_ambient(1:numberofpoints) =  27.722 + 273;
elseif (day < 212) && (day >=181)
    C = .126;
    Temperature_ambient(1:numberofpoints) = 29.444 + 273;
elseif (day < 243) && (day >= 212)
    C = .112;
    Temperature_ambient(1:numberofpoints) = 28.889 + 273;
elseif (day < 273) && (day >= 243)
    C = .082;
    Temperature_ambient(1:numberofpoints) = 25.333 + 273;
elseif (day < 304) && (day >= 273)
    C = 0.063;
    Temperature_ambient(1:numberofpoints) = 18.333 + 273;
elseif (day < 334) && (day >= 304)
    C = 0.053;
    Temperature_ambient(1:numberofpoints) = 11.111 + 273;
else
    C = 0.057;
    Temperature_ambient(1:numberofpoints) = 3.333 + 273;
end
 
Diffuse_Beam(j,i) = C.*I_local.*(1 + cosd(beta)) ./ 2;
Reflected_Beam(j,i) = rho.*I_local.*sind(alpha(j,i) + C).*(sind(beta/2)^2);
Total_Beam(j,i) = Direct_Beam(j,i) + Diffuse_Beam(j,i) + Reflected_Beam(j,i);


 i = i+1;
   
 
end % END WHILE LOOP
    i = 1;
    j = j+1;

 
    
    %{
d1 =(1:numberofpoints);
figure(2)
plot(d1,Total_Beam(day,:))
hold on
xlabel('Number of Half Hours'),ylabel('Total Beam')
axis([0 24 0 1000])
%}
%{
figure(3)
plot(d1,Total_Beam(day,:))
hold on
xlabel('Number of Half Hours'),ylabel('Total Beam')
axis([0 24 0 1000])
 if (day < 32)
    plot(d1,Total_Beam(day,:),'b')
    hold on
    axis([0 24 0 1000])
elseif (day < 59) && (day >= 32)
    plot(d1,Total_Beam(day,:),'r')
    hold on
    axis([0 24 0 1000])
elseif (day < 90) && (day >=59)
    plot(d1,Total_Beam(day,:),'g')
    hold on
    axis([0 24 0 1000])
elseif (day < 120) && (day >=90)
    plot(d1,Total_Beam(day,:),'k')
    hold on
    axis([0 24 0 1000])
elseif (day < 151) && ( day >= 120)
    plot(d1,Total_Beam(day,:),'y')
    hold on
    axis([0 24 0 1000])
elseif (day < 181) && (day >= 151)
    plot(d1,Total_Beam(day,:),'p')
    hold on
    axis([0 24 0 1000])
elseif (day < 212) && (day >=181)
    plot(d1,Total_Beam(day,:),'k')
    hold on
    axis([0 24 0 1000])
elseif (day < 243) && (day >= 212)
    plot(d1,Total_Beam(day,:),'k')
    hold on
    axis([0 24 0 1000])
elseif (day < 273) && (day >= 243)
plot(d1,Total_Beam(day,:),'k')
    hold on
    axis([0 24 0 1000])
elseif (day < 304) && (day >= 273)
plot(d1,Total_Beam(day,:),'k')
    hold on
    axis([0 24 0 1000])
elseif (day < 334) && (day >= 304)
plot(d1,Total_Beam(day,:),'k')
    hold on
    axis([0 24 0 1000])
else
plot(d1,Total_Beam(day,:),'k')
    hold on
    axis([0 24 0 1000])
 end % END 2nd if statement
%}
    
end % END FOR LOOP
   solar_time_matrix;
   solar_angle;
   zenith;
   alpha;
   as;
   cosi;
   Direct_Beam;
   Diffuse_Beam;
   Total_Beam;
   
 o = 2;  
 R = 1;
 C = 2;
x = ones(365,numberofpoints);
while R<=365
  
x(R,:) = (numberofpoints*(R-1)*x(R,:))+1;
R= R+1;
end

t = 0;

while t < numberofpoints
    
    t = t+1;
    
    x(:,t) = x(:,t)+(t-1);

end


x
figure(6)
plot(x',Total_Beam')
axis([0 10000 0 1000])
xlabel('Time [in half hours]'),ylabel('Total Beam')
title('Total Beam Variation Annual')

%{   
d = (1:numberofpoints);
figure(1)
plot(d,Total_Beam(1,:))
xlabel('Number of Half Hours'),ylabel('Total Beam')
%}
   
%{
figure(5)
plot(Total_Beam')
%}


%% Collector Energy Balance

massflownbutane = 7; %kg/s
cp_nbutane = 1900; %J/kg*K
Collector_area = 2100; %m^2 CTC Roof
Solar_transmittance = 0.92; %AE Collector
Solar_Absorptance = 0.96; %AE Collector
Collector_storage = 0; %J 
Global_Conductance = 8; %W/m^2*K
Insolation = Total_Beam * Solar_transmittance;     %correct %W/m^2
G = massflownbutane / Collector_area;
T_f_in = 80 + 273.15;
T_f_out = T_f_in + (50 .* C ./ .126) .* (Insolation ./ 980);
T_f_out_C = T_f_out - 273.15;
F_r = (G * cp_nbutane  .*( T_f_out - T_f_in )) ./ (( Solar_Absorptance .* Insolation) - Global_Conductance * ( T_f_in - Temperature_ambient ));
heat_Useful = F_r .* Insolation .* Solar_Absorptance .* Collector_area - (Global_Conductance .* (T_f_in - Temperature_ambient) .* F_r .* Collector_area);
%Heat_Useful = abs(heat_Useful)
%Heat_lost = (Global_Conductance .* Collector_area .* (T_f_out + 273.15 - Temperature_ambient))
Heat_lost = (Insolation .* Collector_area) - heat_Useful;
Temperaturedifference = heat_Useful ./ (massflownbutane.*cp_nbutane);

T_Collector_out = Temperaturedifference + T_f_in; %K
T_Collector_out_C = T_Collector_out - 273.15; %C

TotalTempchange = sum(Temperaturedifference); % Not used.

Heat_total = heat_Useful + Heat_lost;

Collector_efficiency = heat_Useful ./ Heat_total; % Should be 30-40%
 
 
 









